@@ -1127,7 +1127,7 @@ bool HardwareInfo::setCPUFreq ( cpufreq_type cpufreq, int limit ) {
 	}
 	
 	if (cpuFreqAllowed  == 0) {
-		kdError() << "Could not set CPU Freq, this not the needed privileges." << endl;
+		kdError() << "Could not set CPU Freq - insufficient privileges." << endl;
 		return false;
 	}
 	
